class HubServerConfig(object):

    hub_url = None
    hub_username = None
    hub_password = None

    hub_proxy_host = None
    hub_proxy_port = None
    hub_proxy_username = None
    hub_proxy_password = None

    hub_timeout = 120
    hub_scan_timeout = 300

    def __init__(self):
        pass
