class MetadataView(object):

    allow = None
    href = None
    links = None

    attribute_map = {
        "allow": "allow",
        "href": "href",
        "links": "links"
    }

    def __init__(self):
        pass
