class BdioExternalIdentifier(object):

    forge = None
    external_identifier = None

    attribute_map = {
        "forge": "externalSystemTypeId",
        "external_identifier": "externalId",
    }

    def __init__(self):
        pass
